==> pingdash-0.1.4.tgz: package/src/ping.js <==
const request = require('request')
const normalizeUrl = require('normalize-url')
const exec = require('shelljs').exec

let data = {}

function check(index, option, update, log, error, info) {
  function doit() {
    let startTime = (new Date).getTime()
    let method = option.method
    if (/(POST|GET|PUT|DELETE|HEAD|OPTIONS)/.test(method.toUpperCase())) {
      if (!option.url) {
        info(`${option.name}: no URL set`)
        info(`Skipping...`)
        return
      }
      request({method, url} = option, (err, response, body) => {
        if (err) {
          error(`${option.name} error:`)
          error('>', err.message)
          info(`Skipping...`)

          const time = ((new Date).getTime() - startTime) / 1000
          data.data[index].result = {
            status: -1,
            message: err.message,
            body: null,
            time
          }
        } else {
          const status = response.statusCode
          const message = response.statusMessage
          const time = ((new Date).getTime() - startTime) / 1000
          ;(status >= 400 ? error : log)(`${option.name}: ${status} - ${message} - ${time}s`)
          data.data[index].result = {
            status,
            message,
            body: body ? body.replace(/(^[^]{100})[^]+$/, '$1...') : '',
            time
          }
        }
        update(data)
        setTimeout(doit, option.interval * 1000)
      })
    } else {
      exec(method, {silent: true}, (code, stdout, stderr) => {
        const status = code
        const message = code ? stderr : 'OK'
        const time = ((new Date).getTime() - startTime) / 1000
        ;(code != 0 ? error : log)(`${option.name}: (bash) ${code} - ${message} - ${time}s`)
        data.data[index].result = {
          status,
          message,
          body: stdout ? stdout.replace(/(^[^]{100})[^]+$/ig, '$1...') : '',
          time
        }
        update(data)
        setTimeout(doit, option.interval * 1000)
      })
    }
  }

  doit()
}

function ping(options, update, log, error, info) {
  // setup default data & check
  let siteOptions = options.data.map((site, i) => {
    let option = {
      name: site.name || `Site ${i + 1}`,
      url: site.url ? normalizeUrl(site.url) : null,
      method: site.method || 'GET',
      interval: site.interval ? Math.max(1, Number(site.interval)) : 3,
      result: null
    }
    info(`Start monitoring ${option.name}...`)
    check(i, option, update, log, error, info)

    return option
  })

  data = Object.assign({}, options, {
    data: siteOptions
  })

  // initial update
  info()
  update(data)
}

module.exports = ping

==> pingdash-0.1.5.tgz: package/src/ping.js <==
const request = require('request')
const normalizeUrl = require('normalize-url')
const exec = require('shelljs').exec

let data = {}

function check(index, option, update, log, error, info) {
  function doit() {
    let startTime = (new Date).getTime()
    let method = option.method
    if (/^(POST|GET|PUT|DELETE|HEAD|OPTIONS)$/.test(method.toUpperCase())) {
      if (!option.url) {
        info(`${option.name}: no URL set`)
        info(`Skipping...`)
        return
      }
      request({method, url} = option, (err, response, body) => {
        if (err) {
          error(`${option.name} error:`)
          error('>', err.message)
          info(`Skipping...`)

          const time = ((new Date).getTime() - startTime) / 1000
          data.data[index].result = {
            status: -1,
            message: err.message,
            body: null,
            time
          }
        } else {
          const status = response.statusCode
          const message = response.statusMessage
          const time = ((new Date).getTime() - startTime) / 1000
          ;(status >= 400 ? error : log)(`${option.name}: ${status} - ${message} - ${time}s`)
          data.data[index].result = {
            status,
            message,
            body: body ? body.replace(/(^[^]{100})[^]+$/, '$1...') : '',
            time
          }
        }
        update(data)
        setTimeout(doit, option.interval * 1000)
      })
    } else {
      exec(method, {silent: true}, (code, stdout, stderr) => {
        const status = code
        const message = code ? stderr : 'OK'
        const time = ((new Date).getTime() - startTime) / 1000
        ;(code != 0 ? error : log)(`${option.name}: (bash) ${code} - ${message} - ${time}s`)
        data.data[index].result = {
          status,
          message,
          body: stdout ? stdout.replace(/(^[^]{100})[^]+$/ig, '$1...') : '',
          time
        }
        update(data)
        setTimeout(doit, option.interval * 1000)
      })
    }
  }

  doit()
}

function ping(options, update, log, error, info) {
  // setup default data & check
  let siteOptions = options.data.map((site, i) => {
    let option = {
      name: site.name || `Site ${i + 1}`,
      url: site.url ? normalizeUrl(site.url) : null,
      method: site.method || 'GET',
      interval: site.interval ? Math.max(1, Number(site.interval)) : 3,
      result: null
    }
    info(`Start monitoring ${option.name}...`)
    check(i, option, update, log, error, info)

    return option
  })

  data = Object.assign({}, options, {
    data: siteOptions
  })

  // initial update
  info()
  update(data)
}

module.exports = ping
